pub struct Options {Show 19 fields
pub align_entries: bool,
pub align_comments: bool,
pub align_single_comments: bool,
pub array_trailing_comma: bool,
pub array_auto_expand: bool,
pub inline_table_expand: bool,
pub array_auto_collapse: bool,
pub compact_arrays: bool,
pub compact_inline_tables: bool,
pub compact_entries: bool,
pub column_width: usize,
pub indent_tables: bool,
pub indent_entries: bool,
pub indent_string: String,
pub trailing_newline: bool,
pub reorder_keys: bool,
pub reorder_arrays: bool,
pub allowed_blank_lines: usize,
pub crlf: bool,
}Expand description
All the formatting options.
Fields
align_entries: boolAlign entries vertically.
Entries that have table headers, comments, or blank lines between them are not aligned.
align_comments: boolAlign consecutive comments after entries and items vertically.
This applies to comments that are after entries or array items.
align_single_comments: boolIf align_comments is true, apply the alignment in cases where
there’s only one comment.
array_trailing_comma: boolPut trailing commas for multiline arrays.
array_auto_expand: boolAutomatically expand arrays to multiple lines once they
exceed the configured column_width.
inline_table_expand: boolExpand values (e.g.) inside inline tables where possible.
array_auto_collapse: boolAutomatically collapse arrays if they fit in one line.
The array won’t be collapsed if it contains a comment.
compact_arrays: boolOmit whitespace padding inside single-line arrays.
compact_inline_tables: boolOmit whitespace padding inside inline tables.
compact_entries: boolOmit whitespace around =.
column_width: usizeTarget maximum column width after which arrays are expanded into new lines.
This is best-effort and might not be accurate.
indent_tables: boolIndent subtables if they come in order.
indent_entries: boolIndent entries under tables.
indent_string: StringIndentation to use, should be tabs or spaces but technically could be anything.
trailing_newline: boolAdd trailing newline to the source.
reorder_keys: boolAlphabetically reorder keys that are not separated by blank lines.
reorder_arrays: boolAlphabetically reorder array values that are not separated by blank lines.
allowed_blank_lines: usizeThe maximum amount of consecutive blank lines allowed.
crlf: boolUse CRLF line endings
Implementations
Sourceimpl Options
impl Options
pub fn update(&mut self, incomplete: OptionsIncomplete)
pub fn update_camel(&mut self, incomplete: OptionsIncompleteCamel)
pub fn update_from_str<S: AsRef<str>, I: Iterator<Item = (S, S)>>( &mut self, values: I, ) -> Result<(), OptionParseError>